@@ -41,24 +41,30 @@ def copy(ami_region_pair, args):
     to_region = ami_region_pair[1]
     copied_ami_id = distami.copy_to_region(to_region)
     ami_cp = Distami(copied_ami_id, to_region)
+
     if args.non_public:
         distami.make_ami_non_public()
         distami.make_snapshot_non_public()
     else:
         ami_cp.make_ami_public()
         ami_cp.make_snapshot_public()
+
+    if args.accounts:
+        distami.share_ami_with_accounts(args.accounts)
     
 
 def run():
-    parser = argparse.ArgumentParser(description='Distributes an AMI by copying it to one, many, or all AWS regions, and by optionally making the AMIs and Snapshots public.')
+    parser = argparse.ArgumentParser(description='Distributes an AMI by copying it to one, many, or all AWS regions, and by optionally making the AMIs and Snapshots public or shared with specific AWS Accounts.')
     parser.add_argument('ami_id', metavar='AMI_ID', 
                         help='the source AMI ID to distribute. E.g. ami-1234abcd')
     parser.add_argument('--region', metavar='REGION', 
                         help='the region the AMI is in (default is current region of EC2 instance this is running on). E.g. us-east-1')
     parser.add_argument('--to', metavar='REGIONS', 
-                        help='comma-separated list of regions to copy the AMI to. The default is all regions. E.g. us-east-1,us-west-1,us-west-2')
+                        help='comma-separated list of regions to copy the AMI to. The default is all regions. Specify "none" to prevent copying to other regions. E.g. us-east-1,us-west-1,us-west-2')
     parser.add_argument('--non-public', action='store_true', default=False, 
                         help='Copies the AMIs to other regions, but does not make the AMIs or snapshots public. Bad karma, but good for AMIs that need to be private/internal only')
+    parser.add_argument('--accounts', metavar='AWS_ACCOUNT_IDs', 
+                        help='comma-separated list of AWS Account IDs to share an AMI with. Assumes --non-public. Specify --to=none to share without copying.')
     parser.add_argument('-p', '--parallel', action='store_true', default=False, 
                         help='Perform each copy to another region in parallel. The default is in serial which can take a long time')
     parser.add_argument('-v', '--verbose', action='count', 
@@ -67,6 +73,10 @@ def run():
                         help='display version number and exit')
     args = parser.parse_args()
     
+    # Argument manipulation
+    if args.accounts:
+        args.non_public = True
+    
     Logging().configure(args.verbose)
 
     log.debug("CLI parse args: %s", args)
@@ -90,8 +100,14 @@ def run():
         if not args.non_public:
             distami.make_ami_public()
             distami.make_snapshot_public()
+        if args.accounts:
+            account_ids = args.accounts.split(',')
+            distami.share_ami_with_accounts(account_ids)
+            distami.share_snapshot_with_accounts(account_ids)
         
-        if args.to and args.to != 'all':
+        if args.to and args.to == 'none':
+            to_regions = []
+        elif args.to and args.to != 'all':
             # TODO It is probably worth sanity checking this for typos
             to_regions = args.to.split(',')
         else:
